.. _spkg_pplitepy:

pplitepy: Python pplite wrapper
=========================================

Description
-----------

Python pplite wrapper

License
-------

GPL v3

Upstream Contact
----------------

https://pypi.org/project/pplitepy/


Type
----

optional


Dependencies
------------

- $(PYTHON)
- $(PYTHON_TOOLCHAIN)
- :ref:`spkg_cython`
- :ref:`spkg_flint`
- :ref:`spkg_pplite`

Version Information
-------------------

requirements.txt::

    pplitepy


Equivalent System Packages
--------------------------

(none known)

